import { EditorView } from '@codemirror/view';
import { HighlightStyle, syntaxHighlighting } from '@codemirror/language';
import { tags } from '@lezer/highlight';

// Android Studio theme colors
const base00 = '#282b2e', // Background
base01 = '#a9b7c6', // Foreground
base02 = '#4e5254', // Selection
base03 = '#7f85891f', // Line highlight
base04 = '#00FF00', // Caret
base05 = '#cc7832', // Keyword, Deleted, ClassName
base06 = '#6897bb', // Number, Literal, DerefOperator
base07 = '#629755', // Link, VariableName
base08 = 'grey', // Comment, Quote
base09 = '#bbb529', // Meta, DocumentMeta
base0A = '#6a8759', // String, PropertyName, AttributeValue
base0B = '#ffc66d', // Heading, TypeName
base0C = '#a9b7c6'; // AttributeName
// Define the editor theme styles for Android Studio.
const androidStudioTheme = /*@__PURE__*/EditorView.theme({
    '&': {
        color: base01,
        backgroundColor: base00,
    },
    '.cm-content': {
        caretColor: base04,
    },
    '&.cm-focused .cm-cursor': {
        borderLeftColor: base04,
    },
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': {
        backgroundColor: base02,
    },
    '.cm-activeLine': {
        backgroundColor: base03,
    },
    '.cm-gutters': {
        backgroundColor: base00,
        color: base01,
    },
    '.cm-tooltip': {
        backgroundColor: base01,
    },
}, { dark: true });
// Define the highlighting style for code in the Android Studio theme.
const androidStudioHighlightStyle = /*@__PURE__*/HighlightStyle.define([
    { tag: [tags.keyword, tags.deleted, tags.className], color: base05 },
    { tag: [tags.number, tags.literal, tags.derefOperator], color: base06 },
    { tag: [tags.link, tags.variableName], color: base07 },
    { tag: [tags.comment, tags.quote], color: base08 },
    { tag: [tags.meta, tags.documentMeta], color: base09 },
    { tag: [tags.string, tags.propertyName, tags.attributeValue], color: base0A },
    { tag: [tags.heading, tags.typeName], color: base0B },
    { tag: [tags.attributeName], color: base0C },
    { tag: tags.emphasis, fontStyle: 'italic' },
]);
// Extension to enable the Android Studio theme (both the editor theme and the highlight style).
const androidStudio = [
    androidStudioTheme,
    /*@__PURE__*/syntaxHighlighting(androidStudioHighlightStyle),
];

export { androidStudio, androidStudioHighlightStyle, androidStudioTheme };
